@@ -16,6 +16,7 @@
 /* #undef GOBJECT_STATIC_COMPILATION */
 /* #undef GIO_STATIC_COMPILATION */
 /* #undef GMODULE_STATIC_COMPILATION */
+/* #undef GI_STATIC_COMPILATION */
 /* #undef G_INTL_STATIC_COMPILATION */
 /* #undef FFI_STATIC_BUILD */
 
@@ -113,14 +114,13 @@ typedef unsigned long guintptr;
 #define G_GUINTPTR_FORMAT       "lu"
 
 #define GLIB_MAJOR_VERSION 2
-#define GLIB_MINOR_VERSION 78
-#define GLIB_MICRO_VERSION 3
+#define GLIB_MINOR_VERSION 80
+#define GLIB_MICRO_VERSION 5
 
 #define G_OS_UNIX
 
 #define G_VA_COPY va_copy
 
-#define G_VA_COPY_AS_ARRAY 1
 
 #define G_HAVE_ISO_VARARGS 1
 
